@@ -142,16 +142,8 @@ int HandleWebPages(char *HTTPBuffer, char *HTTPOutputBuffer, int size,
 int Status_Page(char *source, char *dest, int size)
 {
 	if(source && dest && size) {
-		strncpy(dest,
-			"<HTML><BODY><H1><CENTER>Welcome to SNARE for Solaris version 2.5</H1><P>Please select from the menu on the left.</CENTER><p>",
-			size);
-
-		// Ok.. we're cheating here. The only way we can get here is if we're running.
-		strncat(dest,
-			"Status: <font color=green>Snare for Solaris currently running.</font>",
-			size - strlen(dest));
-
-		strncat(dest, "</BODY></HTML>", size - strlen(dest));
+		snprintf(dest,size,
+			"<HTML><BODY><H1><CENTER>Welcome to SNARE for Solaris version 2.5.2</H1><P>Please select from the menu on the left.</CENTER><p>\nStatus: <font color=green>Snare for Solaris currently running.</font>\n</BODY></HTML>");
 	}
 	return (0);
 }
@@ -525,7 +517,7 @@ int Network_Config(char *source, char *dest, int size)
 	}
 
 	strncat(dest,
-		"<br>The following network configuration parameters of the SNARE unit are set to the following values:<br><br>"
+		"<br>The following network configuration parameters of the SNARE unit are set to the following values:<br><br>\n"
 		"<table  width=70% border=0>"
 		"<tr bgcolor=#FFFFCC><td>Clientname</td><td><input type=text name=str_ClientName size=25 value=\"",
 		size - strlen(dest));
@@ -2451,58 +2443,60 @@ int DefaultHeader(char *source, char *dest, int size)
 		"</style>\n"
 		"</head>"
 		"<body text=black bgcolor=white link=#000066 vlink=#000044 alink=#000055>"
-		"<table border=0 cellspacing=0 cellpadding=0 columns=3 width=100%>"
-		"<tbody>"
-		"<tr>"
-		"<td height=70><img src=/intersect.gif alt=\"InterSect\" width=205 height=70 hspace=20 vspace=0 border=0 align=Right>"
-		"</td>"
-		"<td height=70 width=1% bgcolor=#eeeeee><br></td>"
-		"<td height=70 width=1% bgcolor=#dddddd><br></td>"
-		"<td height=70 width=1% bgcolor=#cccccc><br></td>"
-		"<td height=70 width=1% bgcolor=#ccbbbb><br></td>"
-		"<td height=70 width=1% bgcolor=#ccaaaa><br></td>"
-		"<td height=70 width=1% bgcolor=#cc9999><br></td>"
-		"<td height=70 width=1% bgcolor=#cc8888><br></td>"
-		"<td height=70 width=1% bgcolor=#cc7777><br></td>"
-		"<td height=70 width=1% bgcolor=#cc6666><br></td>"
-		"<td height=70 width=1% bgcolor=#cc5555><br></td>"
-		"<td height=70 width=1% bgcolor=#cc4444><br></td>"
-		"<td height=70 width=1% bgcolor=#cc3333><br></td>"
-		"<td height=70 width=1% bgcolor=#cc2222><br></td>"
-		"<td height=70 width=1% bgcolor=#cc1111><br></td>"
-		"<td height=70 width=86% bgcolor=#cc0000><font color=white><center><h1>SNARE for Solaris</h1></center></font></td>"
-		"</tr>"
-		"</tbody>"
-		"</table>"
-		"<table border=0 cellspacing=0 cellpadding=0 columns=1 width=100%>"
-		"<tr><td height=3 border=0 bgcolor=white width=100%></td></tr>"
-		"<tr><td height=3 border=0 bgcolor=black width=100%></td></tr>"
-		"<tr><td height=2 border=0 bgcolor=#AAAAAA width=100%></td></tr>"
-		"<tr><td height=2 border=0 bgcolor=white width=100%></td></tr>"
-		"</table>"
-		"<table border=0 cellspacing=0 cellpadding=5 columns=2 width=100% height=100%>"
-		"<tbody>"
-		"<tr>"
-		"<td valign=Top width=20% bgcolor=#cc0000>"
-		"<div align=Center><font color=#ffffff>"
-		"<br>"
-		"<font face=\"Helvetica,Arial,sans-serif\" size=-1><B>"
-		"<br><A HREF=\"/network\" style=\"color:FFFFFF;text-decoration:none\">Network Configuration</A><br>"
-		"<br><A HREF=\"/remote\" style=\"color:FFFFFF;text-decoration:none\">Remote Control Configuration</A><br>"
-		"<br><A HREF=\"/objective\" style=\"color:FFFFFF;text-decoration:none\">Objectives Configuration</A><br>"
-		"<br><A HREF=\"/status\" style=\"color:FFFFFF;text-decoration:none\">View Audit Service Status</A><br>"
-		"<br><A HREF=\"/restart\" style=\"color:FFFFFF;text-decoration:none\">Apply the Latest Audit Configuration</A><br>"
-		"<br><br><font size=-2><A HREF=\"/Users\" style=\"color:FFFFFF;text-decoration:none\">Display a list of Users</A><br>"
-		"<br><A HREF=\"/Groups\" style=\"color:FFFFFF;text-decoration:none\">Display a list of Groups</A><br>"
-		"<br><A HREF=\"/GroupMembers\" style=\"color:FFFFFF;text-decoration:none\">Display a list of GroupMembers</A><br>"
-		"<br><br><font size=-2><A HREF=\"/Jass\" style=\"color:FFFFFF;text-decoration:none\">Execute the Sun JASS tool</A></font><br>"
-		"</b></font>"
-		"<br>"
-		"</div>"
-		"</td>"
-		"<td width=100% valign=Top>"
-		"<table cellpadding=0 cellspacing=10 border=0 width=100%>"
-		"<tbody>" "<tr>" "<td valign=Top align=Justify>", size);
+		"<table border=0 cellspacing=0 cellpadding=0 width=100%>\n"
+		"<tbody>\n"
+		" <tr>\n"
+		"  <td height=70><img src=/intersect.gif alt=\"InterSect\" width=205 height=70 hspace=20 vspace=0 border=0 align=Right>"
+		"</td>\n"
+		"   <td height=70 width=1% bgcolor=#eeeeee><br></td>"
+		"   <td height=70 width=1% bgcolor=#dddddd><br></td>"
+		"   <td height=70 width=1% bgcolor=#cccccc><br></td>"
+		"   <td height=70 width=1% bgcolor=#ccbbbb><br></td>"
+		"   <td height=70 width=1% bgcolor=#ccaaaa><br></td>"
+		"   <td height=70 width=1% bgcolor=#cc9999><br></td>"
+		"   <td height=70 width=1% bgcolor=#cc8888><br></td>"
+		"   <td height=70 width=1% bgcolor=#cc7777><br></td>"
+		"   <td height=70 width=1% bgcolor=#cc6666><br></td>"
+		"   <td height=70 width=1% bgcolor=#cc5555><br></td>"
+		"   <td height=70 width=1% bgcolor=#cc4444><br></td>"
+		"   <td height=70 width=1% bgcolor=#cc3333><br></td>"
+		"   <td height=70 width=1% bgcolor=#cc2222><br></td>"
+		"   <td height=70 width=1% bgcolor=#cc1111><br></td>\n"
+		"   <td height=70 width=86% bgcolor=#cc0000><font color=white><center><h1>SNARE for Solaris</h1></center></font></td>\n"
+		" </tr>\n"
+		"</tbody>\n"
+		"</table>\n"
+		"<table border=0 cellspacing=0 cellpadding=0 width=100%>\n"
+		" <tr><td height=3 bgcolor=white width=100%></td></tr>\n"
+		" <tr><td height=3 bgcolor=black width=100%></td></tr>\n"
+		" <tr><td height=2 bgcolor=#AAAAAA width=100%></td></tr>\n"
+		" <tr><td height=2 bgcolor=white width=100%></td></tr>\n"
+		"</table>\n"
+		"<table border=0 cellspacing=0 cellpadding=5 width=100% height=100%>\n"
+		"<tbody>\n"
+		" <tr>\n"
+		"  <td valign=Top width=20% bgcolor=#cc0000>\n"
+		"   <div align=Center><font color=#ffffff>\n"
+		"   <br>\n"
+		"   <font face=\"Helvetica,Arial,sans-serif\" size=-1><B>\n"
+		"   <br><A HREF=\"/network\" style=\"color:FFFFFF;text-decoration:none\">Network Configuration</A><br>\n"
+		"   <br><A HREF=\"/remote\" style=\"color:FFFFFF;text-decoration:none\">Remote Control Configuration</A><br>\n"
+		"   <br><A HREF=\"/objective\" style=\"color:FFFFFF;text-decoration:none\">Objectives Configuration</A><br>\n"
+		"   <br><A HREF=\"/status\" style=\"color:FFFFFF;text-decoration:none\">View Audit Service Status</A><br>\n"
+		"   <br><A HREF=\"/restart\" style=\"color:FFFFFF;text-decoration:none\">Apply the Latest Audit Configuration</A><br>\n"
+		"   <br><br><font size=-2><A HREF=\"/Users\" style=\"color:FFFFFF;text-decoration:none\">Display a list of Users</A><br>\n"
+		"   <br><A HREF=\"/Groups\" style=\"color:FFFFFF;text-decoration:none\">Display a list of Groups</A><br>\n"
+		"   <br><A HREF=\"/GroupMembers\" style=\"color:FFFFFF;text-decoration:none\">Display a list of GroupMembers</A><br>\n"
+		"   <br><br><font size=-2><A HREF=\"/Jass\" style=\"color:FFFFFF;text-decoration:none\">Execute the Sun JASS tool</A></font><br>\n"
+		"   </b></font>\n"
+		"   <br>\n"
+		"   </div>\n"
+		"  </td>\n"
+		"  <td width=100% valign=Top>\n"
+		"   <table cellpadding=0 cellspacing=10 border=0 width=100%>\n"
+		"    <tbody>\n"
+		"    <tr>\n"
+		"     <td valign=Top align=Justify>\n", size);
 
 	return (0);
 }
@@ -2514,14 +2508,16 @@ int DefaultFooter(char *source, char *dest, int size)
 		return(0);
 	}
 
-	strncpy(dest, "</td>"
-		"</tr>"
-		"</tbody>"
-		"</table>"
-		"</body><center>"
+	strncpy(dest, "     </td>\n"
+		"    </tr>\n"
+		"    </tbody>\n"
+		"   </table>\n"
+		"<center>\n"
 		"<BR><BR><FONT SIZE=-1>(c) <A HREF=\"http://www.intersectalliance.com\">Intersect Alliance</A> Pty Ltd 1999-2004. "
 		"This site is powered by <A HREF=\"http://www.intersectalliance.com/projects/index.html\">SNARE for Solaris.</A></FONT>"
-		"</center></html>", size);
+		"</center>\n"
+		"</td></tr></tbody></table>\n"
+		"</body></html>", size);
 
 	return (0);
 }
