@@ -12,6 +12,7 @@
 #define SIZE_OF_CLIENTNAME               100
 #define SIZE_OF_DESTINATION              100
 #define SIZE_OF_USER_MATCH_TYPE  10
+#define SIZE_OF_GENERAL_MATCH_TYPE  10
 #define WEB_READ_CONFIG_ERROR_CODE              510000
 #define WEB_READ_NETWORK_ERROR_CODE             530000
 #define WEB_READ_REMOTE_ERROR_CODE              580000
@@ -37,7 +38,7 @@
 #define FILE_WRITE_EVENTS "open_rc,open_rt,open_rtc,open_w,open_wc,open_wt,open_wtc,open_rw,open_rwc,open_rwt,open_rwtc,creat,mkdir,mknod,xmknod,link,symlink,rmdir,unlink,rename,truncate,ftruncate"
 #define FILE_REMOVE_EVENTS "rmdir,unlink"
 #define FILE_ATTRIB_EVENTS "chmod,fchmod,chown,fchown,mctl,fcntl,lchown,aclset,faclset"
-#define PROCESS_EVENTS "exec,execve,exit"
+#define PROCESS_EVENTS "exec,execve"
 #define USER_EVENTS "setgroups,setpgrp,setuid,setgid,seteuid,setegid,setauid,setreuid,setregid,osetuid,osetpgrp"
 #define SOCKET_EVENTS "connect,shutdown,setsockopt"
 
@@ -60,6 +61,7 @@ struct Reg_Config {
 	int dw_DestPort;
 	char str_FileDestination[SIZE_OF_DESTINATION];
 	int dw_stdout;
+	int dw_Syslog;
 };
 
 struct Reg_Remote {
@@ -78,6 +80,7 @@ struct Reg_Objective {
 	char str_user_match[SIZE_OF_USERMATCH];
 	char str_general_match[SIZE_OF_GENERALMATCH];
 	char str_user_match_type[SIZE_OF_USER_MATCH_TYPE];
+	char str_general_match_type[SIZE_OF_GENERAL_MATCH_TYPE];
 };
 
 
@@ -111,6 +114,7 @@ int debracket(char *source, char *dest, int length);
 int ShowUsers(int http_socket);
 int ShowGroups(int http_socket);
 int ShowGroupMembers(int http_socket);
+int RunJass(int http_socket, char *, char *, int);
 
 
 // Stuff we use from webserver.h
