@@ -1,12 +1,12 @@
 /**********************************************************
  *
- * Snare for Solaris version 2.5
+ * Snare for Solaris version 2.5.1
  *
  * Author: InterSect Alliance Pty Ltd
  *
  * Copyright 2001-2004 InterSect Alliance Pty Ltd
  *
- * Last Modified: 5/7/2004
+ * Last Modified: 29/11/2004
  *
  * Available under the terms of the GNU Public Licence.
  * - See www.gnu.org
@@ -65,6 +65,11 @@
  *      26/ 7/2004  Moving back to 'sledge hammer' approach to audit class
  *                  configuration, as auditconfig -conf no longer sets
  *                  process to class mappings properly.
+ *      01/11/2004  Syslog destination now available.
+ *                  JASS able to be called if installed
+ *                  Event match exclusion available.
+ *      30/11/2004  Infrastructure required to read raw bsm logs from the
+ *                  command line, and parse through snare.conf rules.
  *
  **********************************************************
  *
@@ -138,6 +143,7 @@ struct sockaddr_in      AuditSocketName;
 extern int errno;
 int caught_pipe;                /* variable that lets us know when a SIGPIPE has been received */
 int caught_kill;                /* variable that lets us know when a SIGKILL has been received */
+int caught_usr1;                /* variable that lets us know when a SIGUSR1 has been received */
 
 void pipe_signal(sig)
 {
@@ -151,6 +157,11 @@ void kill_signal(sig)
 	return;
 }
 
+void usr1_signal(sig) {
+	caught_usr1++;
+	return;
+}
+
 void audit_off()
 {
 	static int auditingoff = AUC_NOAUDIT;
@@ -172,10 +183,10 @@ int main(int argc, char *argv[])
 	int bytesread;			/* number of bytes read from the pipe */
 	int daemon2praudit[2];		/* Pipe from the daemon to praudit */
 	int praudit2daemon[2];		/* Pipe from praudit back to the daemon */
-	char logbuffer[8192];	/* Holds the data from praudit */
+	char logbuffer[8192];		/* Holds the data from praudit */
 	int logbuffercount=0;		/* current position in the log buffer */
 	int error;
-	int continueloop=1;			/* Make sure we restart praudit if the pipe fails */
+	int continueloop=1;		/* Make sure we restart praudit if the pipe fails */
 
 	/* Signal related variables */
 	sigset_t signalset;
@@ -231,56 +242,63 @@ int main(int argc, char *argv[])
 		close(fd);
 	}
 
-	if(auditon(A_GETCOND,(caddr_t)&auditstatus,sizeof(auditstatus)) == -1)
-	{
-		printf("Could not get auditing condition from the kernel.\nUnable to determine whether auditing has been enabled or not.\n");
-		exit(1);
-	} else {
-		/* Lets make sure that a exec arguments are included in the
-		   audit information, as well as sequence numbers. */
-		if(auditon(A_GETPOLICY,(caddr_t)&auditpolicy,sizeof(auditpolicy)) == -1)
-		{
-			fprintf(stderr,"Could not get auditing condition from the kernel.\nUnable to query the current audit policy.\n");
+	// No arguments provided to the binary?
+	if(argc == 1) {
+		if(auditon(A_GETCOND,(caddr_t)&auditstatus,sizeof(auditstatus)) == -1) {
+			printf("Could not get auditing condition from the kernel.\nUnable to determine whether auditing has been enabled or not.\n");
 			exit(1);
 		} else {
-			/* Turn on some specific audit conditions. */
-			auditpolicy = auditpolicy | AUDIT_ARGV | AUDIT_SEQ | AUDIT_CNT;
-			if(auditon(A_SETPOLICY,(caddr_t)&auditpolicy,sizeof(auditpolicy)) == -1)
+			/* Lets make sure that a exec arguments are included in the
+			   audit information, as well as sequence numbers. */
+			if(auditon(A_GETPOLICY,(caddr_t)&auditpolicy,sizeof(auditpolicy)) == -1)
 			{
-				fprintf(stderr,"Could not set the audit policy to include exec, execv and sequence data in audit information.\n");
+				fprintf(stderr,"Could not get auditing condition from the kernel.\nUnable to query the current audit policy.\n");
 				exit(1);
+			} else {
+				/* Turn on some specific audit conditions. */
+				auditpolicy = auditpolicy | AUDIT_ARGV | AUDIT_SEQ | AUDIT_CNT;
+				if(auditon(A_SETPOLICY,(caddr_t)&auditpolicy,sizeof(auditpolicy)) == -1)
+				{
+					fprintf(stderr,"Could not set the audit policy to include exec, execv and sequence data in audit information.\n");
+					exit(1);
+				}
 			}
 		}
+
+		/* If the kernel is letting us read the audit condition */
+		if(auditstatus == AUC_DISABLED)
+		{
+			fprintf(stderr,"Auditing has not been enabled on this machine!\n");
+			exit(1);
+		}
+
+		/* Set the class of all active processes to our custom class. */
+		setclass(0x10000000);
+
 	}
 
-
-
-
-	/* If the kernel is letting us read the audit condition */
-	if(auditstatus == AUC_DISABLED)
-	{
-		fprintf(stderr,"Auditing has not been enabled on this machine!\n");
-		exit(1);
-	}
-
-	/* Set the class of all active processes to our custom class. */
-	setclass(0x10000000);
-
-
 	/* Make sure that we divorce ourselves from the parent process
 	   as we may do not want to inherit signals
 	   Note that we will definately be divorced from the parent tty
 	   after this, so error messages to stdout will not be particularly
 	   useful. */
 
-	if(fork())	{
-		/* This is the parent process - exit, and ditch the parent.
-		   We will be inherited by process 1 (init) */
-		exit(0);
+	if(argc == 1) {
+		if(fork())	{
+			/* This is the parent process - exit, and ditch the parent.
+			   We will be inherited by process 1 (init) */
+			exit(0);
+		}
 	}
 
 	// Read our configuration file, and set up audit.
-	read_config_file(0);
+	if(argc == 1) {
+		read_config_file(0);
+	} else {
+		read_config_file(1);
+		// No point in turning on the web server.
+		remote_allow=0;
+	}
 		
 	if(!hostid) {
 		getfqdn(hostid);
@@ -296,7 +314,7 @@ int main(int argc, char *argv[])
 	if(!ppid)
 	{
 		fprintf(stderr,"Cannot find current process ID. Exiting.\n");
-		audit_off();
+		if(argc == 1) { audit_off(); }
 		exit(1);
 	} else {
 		/* Write out process ID */
@@ -308,29 +326,30 @@ int main(int argc, char *argv[])
 	}
 
 	
-	
-	 
-	// ceci n'est pas une pipe
 	// Hopefully, we'll be able to kill off praudit when/if Sun
 	// open-source Solaris..
+	 
+	// ceci n'est pas une pipe
 	if (pipe(daemon2praudit) == -1 || pipe(praudit2daemon) == -1)
 	{
 		fprintf(stderr,"Cannot open pipe for audit information\n");
 		kill(ppid,SIGTERM); waitpid(pid,NULL,NULL);
-		audit_off();
+		if(argc == 1) { audit_off(); }
 		exit(1);
 	}
 
 	// This is effectively a while(true)
 	while(continueloop)
 	{
-		// Ok. We should be just about ready to audit now.
-		// Lets tell the kernel.
+		if(argc == 1) {
+			// Ok. We should be just about ready to audit now.
+			// Lets tell the kernel.
 	
-		if (!audit_on()) {
-			fprintf(stderr,"Cannot start auditing!\n");
-			kill(ppid,SIGTERM); waitpid(pid,NULL,NULL);
-        		exit(1);
+			if (!audit_on()) {
+				fprintf(stderr,"Cannot start auditing!\n");
+				kill(ppid,SIGTERM); waitpid(pid,NULL,NULL);
+        			exit(1);
+			}
 		}
 
 		// Configure / Reinstate signals
@@ -342,7 +361,7 @@ int main(int argc, char *argv[])
 		if(!setsignals(&signalset)) {
 			fprintf(stderr,"Cannot set important signals - exiting\n");
 			kill(ppid,SIGTERM); waitpid(pid,NULL,NULL);
-			audit_off();
+			if(argc == 1) { audit_off(); }
 			continueloop=0;
 			break;
 		}
@@ -382,7 +401,7 @@ int main(int argc, char *argv[])
 		{
 			fprintf(stderr,"Could not fork a process to run praudit\n");
 			kill(ppid,SIGTERM); waitpid(pid,NULL,NULL);
-			audit_off();
+			if(argc == 1) { audit_off(); }
 			break;
 		} else if(pid == 0) {
 			// Fork child process
@@ -391,7 +410,7 @@ int main(int argc, char *argv[])
 			  case -1:
 				fprintf(stderr,"fork failure. Cannot start the praudit and auditsvc fork.\n");
 				kill(ppid,SIGTERM); waitpid(pid,NULL,NULL);
-				audit_off();
+				if(argc == 1) { audit_off(); }
 				exit(1);
 		
 			  case 0:
@@ -403,7 +422,7 @@ int main(int argc, char *argv[])
 				    )
 				{
 					fprintf(stderr,"Could not reroute stdin and stdout for praudit\n");
-					audit_off();
+					if(argc == 1) { audit_off(); }
 					kill(ppid,SIGTERM); waitpid(pid,NULL,NULL);
 					exit(1);
 				}
@@ -418,7 +437,7 @@ int main(int argc, char *argv[])
 
 				// We should never actually get here
 				fprintf(stderr,"Could not exec praudit\n");
-				audit_off();
+				if(argc == 1) { audit_off(); }
 				kill(ppid,SIGTERM); waitpid(pid,NULL,NULL);
 				exit(1);
 				
@@ -427,6 +446,35 @@ int main(int argc, char *argv[])
 				// Close unused fildes
 				close(daemon2praudit[0]);
 				close(praudit2daemon[1]);
+
+				// HERE: if we have been asked to grab files from the command line, read them here.
+				if(argc > 1) {
+					int i=0;
+					int auditfile;
+					ssize_t readbytes;
+					ssize_t writebytes;
+					char buf[4096];
+					pid_t ppid=getppid();
+
+					for(i=1;i<argc;i++) {
+						fprintf(stderr,"Processing %s..\n",argv[i]);
+						auditfile=open(argv[i],O_RDONLY);
+						if(auditfile==-1) {
+							fprintf(stderr,"Cannot open file %s\n",argv[i]);
+						}
+						while(readbytes=read(auditfile,buf,sizeof(buf))) {
+							writebytes=write(daemon2praudit[1],buf,readbytes);
+						}
+						close(auditfile);
+					}
+
+					if(ppid) {
+						kill(ppid,SIGUSR1);
+					}
+
+					close(daemon2praudit[1]);
+					exit(1);
+				}
 			
 				// Loop for as long as we don't receive a signal
 				while(1)
@@ -438,7 +486,6 @@ int main(int argc, char *argv[])
 					   better be installed before we make this
 					   system call, or the machine will halt! */
 
-
 					auditsvc(daemon2praudit[1],0);
 					error=errno;
 
@@ -448,14 +495,14 @@ int main(int argc, char *argv[])
 						/* Auditing dissapeared from under us? */
 						fprintf(stderr,"SNARE reports that auditing has been turned off. Exiting.\n");
 						// Just in case.
-						audit_off();
+						if(argc == 1) { audit_off(); }
 						unlink("/var/run/snarecore.pid");
 						kill(ppid,SIGTERM); waitpid(pid,NULL,NULL);
 						exit(1);
 					} else if(error == EBUSY) {
 						/* Auditing is already being performed by another process */
 						fprintf(stderr,"Another process has control of audit.\n");
-						audit_off();
+						if(argc == 1) { audit_off(); }
 						if(webpid) {
 							kill(webpid,SIGTERM);
 						}
@@ -497,6 +544,9 @@ int main(int argc, char *argv[])
 			char options[MAX_OPTIONS]="";
 			char *startrecord=logbuffer;
 			int returncode;
+			int datacheck;
+			struct timeval tv;
+			fd_set rfds;
 
 			char *tbuffer;
 			/* Setup a kill signal handler so that when the primary
@@ -505,15 +555,13 @@ int main(int argc, char *argv[])
 			if(signal(SIGTERM,kill_signal) == SIG_ERR)
 			{
 				fprintf(stderr,"Cannot set signal SIGTERM\n");
-				audit_off();
+				if(argc == 1) { audit_off(); }
 				kill(ppid,SIGTERM); waitpid(pid,NULL,NULL);
 				exit(1);
 			}
 
 			logbuffercount=0;
 
-
-			// while ((bytesread=read(praudit2daemon[0],bufferptr,spaceavail) >0) && continueloop)
 			while (continueloop && !caught_kill) {
 				if(spaceavail==0) {
 					// Oh dear.. filled our buffer without seeing a newline. Must be filled with corrupt data from praudit.
@@ -522,6 +570,24 @@ int main(int argc, char *argv[])
 					spaceavail=buffersize;
 				}
 
+				FD_ZERO(&rfds);
+				FD_SET(praudit2daemon[0], &rfds);
+				/* Wait up to three seconds. */
+	   			tv.tv_sec = 3;
+	   			tv.tv_usec = 0;
+				datacheck = select(praudit2daemon[0]+1, &rfds, NULL, NULL, &tv);
+				if(!datacheck) {
+					// Grabbed a usr1? Are we processing files? If not, ignore it.
+					if(caught_usr1 && argc > 1) {
+						fprintf(stderr,"Completed file analysis.\n");
+						close(praudit2daemon[0]);
+						caught_kill=1;
+						break;
+					} else {
+						continue;
+					}
+				}
+
 				bytesread=read(praudit2daemon[0],bufferptr,spaceavail);
 				if(!bytesread) {
 					break;
@@ -579,7 +645,7 @@ int main(int argc, char *argv[])
 				/* Take our other processes down with it. */
 				/* Kill the other child process (auditsvc),
 				   and restart praudit and auditsvc */
-				audit_off();
+				if(argc == 1) { audit_off(); }
 				kill(pid,SIGTERM);
 				/* Wait for the process to die */
 				waitpid(pid,NULL,NULL);
@@ -600,8 +666,6 @@ int main(int argc, char *argv[])
 				/* All done */
 				return 0;
 			} else if(caught_pipe) {
-
-
 				/* Oh dear, our child process has been terminated. */
 				caught_pipe=0;
 				/* Kill the other child process (auditsvc),
@@ -633,7 +697,7 @@ int main(int argc, char *argv[])
 	unlink("/var/run/snarecore.pid");
 			
 	/* All done */
-	audit_off();
+	if(argc == 1) { audit_off(); }
 	return 0;
 }
 
@@ -645,9 +709,16 @@ int setsignals(sigset_t *signalset)
 	sigdelset(signalset,SIGALRM);
 	sigdelset(signalset,SIGINT);
 	sigdelset(signalset,SIGPIPE);
+	sigdelset(signalset,SIGUSR1);
 	sigdelset(signalset,SIGCHLD);
 	sigprocmask(SIG_BLOCK,signalset, (void *) NULL);
 
+	if(signal(SIGUSR1,usr1_signal) == SIG_ERR)
+	{
+		fprintf(stderr,"Cannot set signal SIGUSR1\n");
+		return(0);
+	}
+
 	if(signal(SIGPIPE,pipe_signal) == SIG_ERR)
 	{
 		fprintf(stderr,"Cannot set signal SIGPIPE\n");
@@ -665,7 +736,6 @@ int setsignals(sigset_t *signalset)
 
 int turn_event_on(int eventnumber)
 {
-	//struct au_evclass_map map;
 	au_evclass_map_t map;
 	int returncode;
 
@@ -804,9 +874,8 @@ int flush_audit_events()
 	return(1);
 }
 
-
-// Shortread: don't re-read all the objectives - just the general configuration items.
-int read_config_file(int shortread)
+// nosetaudit: whether to set auditing up or not..
+int read_config_file(int nosetaudit)
 {
 	FILE * configfile = (FILE *)NULL;
 	char inputbuffer[MAX_AUDIT_CONFIG_LINE];	// Should be enough for most config lines.
@@ -851,11 +920,6 @@ int read_config_file(int shortread)
 					int excludeflag=0;
 					int excludematchflag=0;
 
-					// Do we need to skip over the objectives?
-					if(shortread==1) {
-						continue;
-					}
-					
 					if((criticality = splitobjective(inputbuffer,event,user,path,&excludeflag,&excludematchflag,&returncode)) > -1) {
 						// add the objective to the linked list.
 						trimallwhitespace(event);
@@ -898,9 +962,10 @@ int read_config_file(int shortread)
 							if((eventnumber = eventname2number(event2)) > -1) {
 								AddToList(event2,user,path,criticality,options,excludeflag,excludematchflag,returncode);
 
-								// Also, ensure this event is turned on
-
-								turn_event_on(eventnumber);
+								if(!nosetaudit) {
+									// Also, ensure this event is turned on
+									turn_event_on(eventnumber);
+								}
 
 							} else {
 								if(!strcmp(event,"*")) {
