@@ -204,9 +204,9 @@ int HandleConnect()
 		retval =
 		    send(http_message_socket, HTTPOutputBuffer, size, 0);
 
-		if (retval == -1) {
-			perror("send() failed");
-		}
+		//if (retval == -1) {
+		//	perror("send() failed");
+		//}
 	}
 
 	shutdown(http_message_socket,SHUT_RDWR);
@@ -523,7 +523,7 @@ int MatchAuth(char *AuthStart)
 	crypttext=crypt(SnarePass,SALT);
 	if(crypttext) {
 		if(!strcmp(AuthString2,crypttext)) {
-			fprintf(stderr,"SNARE Warning: Non-encrypted password used in snare.conf file.\n");
+			// fprintf(stderr,"SNARE Warning: Non-encrypted password used in snare.conf file.\n");
 			return(1);
 		}
 	}
